Crate rippling_api

Crate rippling_api 

A fully generated & opinionated API client for the Rippling API.

docs.rs

API Details

Documentation for the Rippling Platform API.

Client Details

The documentation for the crate is generated along with the code to make this library easy to use.

To install the library, add the following to your Cargo.toml file.

[dependencies]
rippling-api = "0.1.10"

Basic example

Typical use will require intializing a Client. This requires a user agent string and set of credentials.

use rippling_api::Client;

let client = Client::new(String::from("api-key"));

Alternatively, the library can search for most of the variables required for the client in the environment:

  • RIPPLING_API_TOKEN

And then you can create a client from the environment.

use rippling_api::Client;

let client = Client::new_from_env();

Modules

candidate_applicationsrequests
An application by a candidate to a specific job requisition.
candidatesrequests
Someone who applies to a job requisition opened by the company.
companiesrequests
Companies on Rippling.
compensationsrequests
Compensation associated with workers.
custom_fieldsrequests
Custom fields defined by the company.
custom_object_fieldsrequests
Custom object fields defined by the company.
custom_object_recordsrequests
Custom object datarows defined by the company.
custom_objectsrequests
Custom objects defined by the company.
departmentsrequests
Departments used by the company.
employment_typesrequests
Employment types used by the company.
entitlementsrequests
Availability of API features to the company or Partners.
jobrequests
Job related information for the company.
job_requisitionsrequests
A request for a job to be filled by a candidate.
leave_balancesrequests
Leave balances for workers.
leave_requestsrequests
Leave requests submitted by workers.
leave_typesrequests
Leave types used by the company.
legal_entitiesrequests
Legal entities registered by the company.
merequests
Provides the user’s SSO information.
object_categoriesrequests
Object Categories defined by the company.
shift_inputsrequests
Shift inputs used by the company.
teamsrequests
Teams at the company.
time_entriesrequests
Time entries submitted by workers.
tracks_and_levelsrequests
Levels and tracks used by the company for workers.
types
This module contains the generated types for the library.
usersrequests
Users of the company.
utils
work_locationsrequests
Work locations used by the company.
workersrequests
Workers who work or have worked at the company.

Structs

Clientrequests
Entrypoint for interacting with the API client.
RequestBuilderretry and requests
A request builder.