A fully generated & opinionated API client for the Rippling API.
API Details
Documentation for the Rippling Platform API.
Client Details
The documentation for the crate is generated along with the code to make this library easy to use.
To install the library, add the following to your Cargo.toml file.
[dependencies]
rippling-api = "0.1.10"Basic example
Typical use will require intializing a Client. This requires
a user agent string and set of credentials.
use rippling_api::Client;
let client = Client::new(String::from("api-key"));Alternatively, the library can search for most of the variables required for the client in the environment:
RIPPLING_API_TOKEN
And then you can create a client from the environment.
use rippling_api::Client;
let client = Client::new_from_env();Modules
- candidate_
applications requests - An application by a candidate to a specific job requisition.
- candidates
requests - Someone who applies to a job requisition opened by the company.
- companies
requests - Companies on Rippling.
- compensations
requests - Compensation associated with workers.
- custom_
fields requests - Custom fields defined by the company.
- custom_
object_ fields requests - Custom object fields defined by the company.
- custom_
object_ records requests - Custom object datarows defined by the company.
- custom_
objects requests - Custom objects defined by the company.
- departments
requests - Departments used by the company.
- employment_
types requests - Employment types used by the company.
- entitlements
requests - Availability of API features to the company or Partners.
- job
requests - Job related information for the company.
- job_
requisitions requests - A request for a job to be filled by a candidate.
- leave_
balances requests - Leave balances for workers.
- leave_
requests requests - Leave requests submitted by workers.
- leave_
types requests - Leave types used by the company.
- legal_
entities requests - Legal entities registered by the company.
- me
requests - Provides the user’s SSO information.
- object_
categories requests - Object Categories defined by the company.
- shift_
inputs requests - Shift inputs used by the company.
- teams
requests - Teams at the company.
- time_
entries requests - Time entries submitted by workers.
- tracks_
and_ levels requests - Levels and tracks used by the company for workers.
- types
- This module contains the generated types for the library.
- users
requests - Users of the company.
- utils
- work_
locations requests - Work locations used by the company.
- workers
requests - Workers who work or have worked at the company.
Structs
- Client
requests - Entrypoint for interacting with the API client.
- Request
Builder retryandrequests - A request builder.